@@ -47,11 +47,20 @@ typedef Glib::ListHandle< Glib::RefPtr<const Uri> > ListHandleUris;
 typedef sigc::slot<bool, const ProgressInfo&> SlotProgress;
 
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void transfer_list(const Glib::StringArrayHandle& source_uri_list, const Glib::StringArrayHandle& target_uri_list,
       TransferOptions options,
       ErrorMode error_mode,
       OverwriteMode overwrite_mode,
       const SlotProgress& slot);
+#else
+void transfer_list(const Glib::StringArrayHandle& source_uri_list, const Glib::StringArrayHandle& target_uri_list,
+      TransferOptions options,
+      ErrorMode error_mode,
+      OverwriteMode overwrite_mode,
+      const SlotProgress& slot,
+      std::auto_ptr<Gnome::Vfs::exception> error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
       
 /**
  * @source_uri_list: A list of uris  (ie file;//)
@@ -72,45 +81,96 @@ void transfer_list(const Glib::StringArrayHandle& source_uri_list, const Glib::S
  * your application can use to control how the transfer is done.
  *
  */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void transfer_list_uris(const ListHandleUris& source_uri_list, const ListHandleUris& target_uri_list,
       TransferOptions options = XFER_DEFAULT, //TODO: Does Default do anything useful?
       ErrorMode error_mode = XFER_ERROR_MODE_ABORT,
       OverwriteMode overwrite_mode = XFER_OVERWRITE_MODE_ABORT,
       const SlotProgress& progress_callback = SlotProgress());
+#else
+void transfer_list_uris(const ListHandleUris& source_uri_list, const ListHandleUris& target_uri_list,
+      TransferOptions options, //TODO: Does Default do anything useful?
+      ErrorMode error_mode,
+      OverwriteMode overwrite_mode,
+      const SlotProgress& progress_callback,
+      std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void transfer(const Glib::ustring& source_uri, const Glib::ustring& target_uri,
       TransferOptions options = XFER_DEFAULT, //TODO: Does Default do anything useful?
       ErrorMode error_mode = XFER_ERROR_MODE_ABORT,
       OverwriteMode overwrite_mode = XFER_OVERWRITE_MODE_ABORT,
       const SlotProgress& progress_callback = SlotProgress());
+#else
+void transfer(const Glib::ustring& source_uri, const Glib::ustring& target_uri,
+      TransferOptions options, //TODO: Does Default do anything useful?
+      ErrorMode error_mode,
+      OverwriteMode overwrite_mode,
+      const SlotProgress& progress_callback,
+      std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
       
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void transfer(const Glib::RefPtr<const Uri>& source_uri, const Glib::RefPtr<const Uri>& target_uri,
       TransferOptions options = XFER_DEFAULT, //TODO: Does Default do anything useful?
       ErrorMode error_mode = XFER_ERROR_MODE_ABORT,
       OverwriteMode overwrite_mode = XFER_OVERWRITE_MODE_ABORT,
       const SlotProgress& progress_callback = SlotProgress());
+#else
+void transfer(const Glib::RefPtr<const Uri>& source_uri, const Glib::RefPtr<const Uri>& target_uri,
+      TransferOptions options, //TODO: Does Default do anything useful?
+      ErrorMode error_mode,
+      OverwriteMode overwrite_mode,
+      const SlotProgress& progress_callback,
+      std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 //TODO: Add a string-based version of gnome_vfs_xfer_delete() to gnome-vfs.
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove(const Glib::ustring& source_uri,
       TransferOptions options = XFER_DEFAULT,
       ErrorMode error_mode = XFER_ERROR_MODE_ABORT,
       const SlotProgress& progress_callback = SlotProgress());
+#else
+void remove(const Glib::ustring& source_uri,
+      TransferOptions options,
+      ErrorMode error_mode,
+      const SlotProgress& progress_callback,
+      std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
       
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove(const Glib::RefPtr<const Uri>& source_uri,
       TransferOptions options = XFER_DEFAULT,
       ErrorMode error_mode = XFER_ERROR_MODE_ABORT,
       const SlotProgress& progress_callback = SlotProgress());
+#else
+void remove(const Glib::RefPtr<const Uri>& source_uri,
+      TransferOptions options,
+      ErrorMode error_mode,
+      const SlotProgress& progress_callback,
+      std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 void remove_list(const Glib::StringArrayHandle& source_uri_list,
       TransferOptions options = XFER_DEFAULT,
       ErrorMode error_mode = XFER_ERROR_MODE_ABORT,
       const SlotProgress& progress_callback = SlotProgress());
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_list_uris(const ListHandleUris& source_uri_list,
       TransferOptions options = XFER_DEFAULT,
       ErrorMode error_mode = XFER_ERROR_MODE_ABORT,
       const SlotProgress& progress_callback = SlotProgress());
+#else
+void remove_list_uris(const ListHandleUris& source_uri_list,
+      TransferOptions options,
+      ErrorMode error_mode,
+      const SlotProgress& progress_callbacki,
+      std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 } // namespace Transfer
 } // namespace Vfs
